@@ -1,14 +1,11 @@
 from abc import ABC, abstractmethod
 from typing import List
 
-from arrow_bpmn.__spi__.execution import State
-from arrow_bpmn.parser.xml.xml_element import XMLElement
-
 
 class BpmnEdge(ABC):
 
-    def __init__(self, element: XMLElement):
-        self.__dict__ = element.get_attributes()
+    def __init__(self, attributes: dict):
+        self.__dict__ = attributes
 
     @property
     def source_ref(self) -> str:
@@ -46,10 +43,6 @@ class BpmnEdge(ABC):
 
         return self.__dict__["id"]
 
-    @abstractmethod
-    def evaluate(self, state: State) -> bool:
-        pass
-
 
 class IncomingEdgeAware(ABC):
 
