@@ -1,5 +1,6 @@
+import logging
 from dataclasses import dataclass, field
-from typing import Optional, List
+from typing import List
 
 from arrow_dmn.engine.sync_dmn_engine import SyncDmnEngine
 
@@ -11,7 +12,7 @@ from arrow_bpmn.__spi__.factory.business_rule_factory import BusinessRuleFactory
 from arrow_bpmn.__spi__.factory.script_factory import ScriptFactory
 from arrow_bpmn.__spi__.factory.service_factory import NoOpServiceFactory
 from arrow_bpmn.__spi__.registry.event import Event
-from arrow_bpmn.__spi__.types import BpmnSource
+from arrow_bpmn.__spi__.types import BpmnSource, OptDict
 from arrow_bpmn.engine.event.eager_event_emitter import EagerEventEmitter
 from arrow_bpmn.engine.execution.cacheable_script_factory import CacheableScriptFactory
 from arrow_bpmn.engine.interceptor.abstract_bpmn_engine_interceptor import BpmnEngineInterceptor
@@ -41,26 +42,31 @@ class BpmnEngine:
     def __post_init__(self):
         self.factories = BpmnFactories(self.script_factory, self.service_factory, self.business_rule_factory)
 
-    def deploy(self, source: BpmnSource) -> List[ProcessRef]:
+    def deploy(self, group: str, source: BpmnSource) -> List[ProcessRef]:
         deployed_processes = []
-        definitions_id, processes = self.parser.parse(source)
+        processes = self.parser.parse(source)
         for process in processes:
-            process_ref = ProcessRef(definitions_id, process.id)
+            process_ref = ProcessRef(group, process.id)
+            if self.process_store.has_process(process_ref):
+                logging.info("process already deployed, start undeploying process")
+                self.undeploy(process_ref)
+
             process.with_event_registry(process_ref, self.event_registry)
-            self.process_store.write_process(definitions_id, process)
+            self.process_store.write_process(group, process)
 
             deployed_processes.append(process_ref)
 
         return deployed_processes
 
     def undeploy(self, process_ref: ProcessRef):
+        self.event_registry.delete_subscriptions(process_ref)
         self.process_store.delete_process(process_ref)
 
-    def invoke_by_event(self, event: Event, init_state: Optional[dict] = None) -> List[State]:
+    def invoke_by_event(self, event: Event, init_state: OptDict = None) -> List[State]:
         pass
 
-    def resume_by_event(self, event: Event) -> List[State]:
+    def resume_by_event(self, event: Event, init_state: OptDict = None) -> List[State]:
         pass
 
-    def invoke_by_id(self, process: ProcessRef, init_state: Optional[dict] = None) -> State:
+    def invoke_by_id(self, process: ProcessRef, init_state: OptDict = None) -> State:
         pass
