@@ -5,6 +5,7 @@ from typing import Optional
 
 from scriptable.abstract_engine import ScriptableEngine
 from scriptable.hypothesis_engine import HypothesisEngine
+from scriptable.mustache_engine import MustacheEngine
 from scriptable.typescript_engine import TypescriptEngine
 
 from arrow_bpmn.__spi__.factory.script_factory import ScriptFactory
@@ -48,5 +49,9 @@ class CacheableScriptFactory(ScriptFactory):
             engine = HypothesisEngine.parse(script)
             self.cache[key] = engine
             return engine
+        if language == "mustache":
+            engine = MustacheEngine.parse(script)
+            self.cache[key] = engine
+            return engine
         else:
             raise ValueError(f"cannot initialize script engine for {language}")
