@@ -1,4 +1,4 @@
-from typing import Dict
+from typing import Dict, Optional
 
 from arrow_bpmn.__spi__ import State, NodeRef
 from arrow_bpmn.engine.registry.abstract_event_registry import ProcessRef
@@ -18,8 +18,8 @@ class InMemoryProcessStore(ProcessStore):
     def delete_process(self, process_ref: ProcessRef):
         del self.process_cache[str(process_ref)]
 
-    def read_process(self, ref: ProcessRef) -> Process:
-        return self.process_cache[str(ref)]
+    def read_process(self, ref: ProcessRef) -> Optional[Process]:
+        return self.process_cache[str(ref)] if str(ref) in self.process_cache else None
 
     def write_state(self, state: State):
         self.state_cache[str(state.reference)] = state
