@@ -16,6 +16,7 @@ from arrow_bpmn.model.event.startevent.none_start_event import NoneStartEvent
 from arrow_bpmn.model.event.startevent.signal_start_event import SignalStartEvent
 from arrow_bpmn.model.gateway.exclusive_gateway import ExclusiveGateway
 from arrow_bpmn.model.process import Process, EventDict
+from arrow_bpmn.model.sequence.association import Association
 from arrow_bpmn.model.sequence.sequence_flow import SequenceFlow
 from arrow_bpmn.model.task.business_rule_task import BusinessRuleTask
 from arrow_bpmn.model.task.call_activity import CallActivity, VariableMapping, ExpressionMapping
@@ -36,6 +37,7 @@ class JsonBpmnParser(BpmnParser):
         # group = element["group"]
 
         sequence_flows = [self._parse_sequence_flow(JSONElement(x)) for x in element.pop("sequence_flows")]
+        associations = [self._parse_association(JSONElement(x)) for x in element.pop("associations")]
         start_events = [self._parse_start_event(JSONElement(x)) for x in element.pop("start_events")]
         end_events = [self._parse_end_event(JSONElement(x)) for x in element.pop("end_events")]
         boundary_events = [self._parse_boundary_event(JSONElement(x)) for x in element.pop("boundary_events")]
@@ -46,12 +48,15 @@ class JsonBpmnParser(BpmnParser):
         events = element.pop("events")
         events = EventDict(events["item"])
 
-        return "group", [Process(element.as_dict(), sequence_flows, tasks, start_events, end_events,
+        return "group", [Process(element.as_dict(), sequence_flows, associations, tasks, start_events, end_events,
                                  boundary_events, intermediate_events, gateways, events)]
 
     def _parse_sequence_flow(self, element: JSONElement):
         return SequenceFlow.from_json(element.get_object("item"))
 
+    def _parse_association(self, element: JSONElement):
+        return Association(element.get_object("item").as_dict())
+
     def _parse_start_event(self, element: JSONElement):
         _type = element["type"]
         _item = element.get_object("item")
